<?php
/*
 * © Copyright 2007, 2008 IntraHealth International, Inc.
 * 
 * This File is part of iHRIS
 * 
 * iHRIS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/**
 * @package iHRIS
 * @subpackage Manage
 * @author Luke Duncan <lduncan@intrahealth.org>
 * @copyright Copyright &copy; 2007, 2008 IntraHealth International, Inc. 
 * @since v1.0.0
 * @version v2.0.0
 */
/**
 * Object for dealing with benefits for people.
 * 
 * @package iHRIS
 * @subpackage Manage
 * @access public
 */
class iHRIS_Benefit extends I2CE_Form {

    const RECURRENCE_ONCE = 1;
    const RECURRENCE_WEEKLY = 2;
    const RECURRENCE_MONTHLY = 3;
    const RECURRENCE_YEARLY = 4;

    /**
     * @var array $recurrence The possible values for recurrence for benefits.
     */
    private static $recurrence = array(
        self::RECURRENCE_ONCE => 'Once',
        self::RECURRENCE_WEEKLY => 'Weekly',
        self::RECURRENCE_MONTHLY => 'Monthly',
        self::RECURRENCE_YEARLY => 'Yearly',
        );

    /**
     * Create a new instance of a benefit.
     * 
     * @param string $form The name of this form
     * @param integer $id
     */
    public function __construct( $form, $id = 0 ) {
        parent::__construct( $form, $id );                
        $this->end_date = I2CE_Date::blank();           
        
    }
 
    /**
     * Lookup the given value from the recurrence array.
     * @param integer $id
     * @param string $form Not used for this method.
     * @return string
     */
    static public function lookupRecurrence( $id, $form="" ) {
        return I2CE_Form::lookupArray( $id, self::$recurrence );
    }
    /**
     * List all the options from the recurrence array.
     * @param string $form The  form we wish to lookup by
     * @returns array
     */
    static public function listRecurrenceOptions($form) {
        return  self::$recurrence ;
    }
         
}

# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
