<?php
/*
 * © Copyright 2007, 2008 IntraHealth International, Inc.
 * 
 * This File is part of iHRIS
 * 
 * iHRIS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/**
 * @package iHRIS
 * @subpackage Manage
 * @author Luke Duncan <lduncan@intrahealth.org>
 * @copyright Copyright &copy; 2007, 2008 IntraHealth International, Inc. 
 * @since v1.0.0
 * @version v2.0.0
 */
/**
 * Object for dealing with jobs.
 * 
 * @package iHRIS
 * @subpackage Manage
 * @access public
 */
class iHRIS_Job extends I2CE_List {

    /**
     * The main field name used for display a description of a record.
     */
    const MAIN_FIELD = "title";

    /**
     * Create a new instance of a job.
     * 
     * @param string $form The name of this form
     * @param integer $id
     */
    public function __construct( $form, $id = 0 ) {
        parent::__construct( $form, $id );
        $this->fields['type']->setValue( $form );
    }

    /**
     * List all jobs by classification (the linked form for this object).
     * 
     * This will return an array that includes all classification codes with all jobs that
     * are in that classification.
     * @return array
     */
    static public function getOptionsByLink() {
        $factory = I2CE_FormFactory::instance();
        return parent::_getOptionsByLink( $factory->getFormName( get_class() ), self::MAIN_FIELD, "classification" );
    }

    /**
     * Return the list of record ids that have this position as supervisor.
     * @return array
     */
    public function getPositions() {
        $job_det = I2CE_FormField::getFormFieldIdAndType( "position", "job" );
        if ( !$job_det ) return array();
        
        $db = MDB2::singleton();
        if ( !I2CE::pearError( $db, "Error getting database connection: " ) ) {
        
            $sth = $db->prepare( "SELECT record FROM last_entry WHERE form_field = ? AND " . $job_det['type'] . "_value = ?", 
                                 array('integer', 'integer'), MDB2_PREPARE_RESULT );
            if ( !I2CE::pearError( $sth, "Error preparing position list: " ) ) {
                $results = $sth->execute( array( $job_det['id'], $this->id ) );
                if ( !I2CE::pearError( $results, "Error executing position list: " ) ) {
                    $positions = array();
                    while( $row = $results->fetchRow() ) {
                        $positions[] = $row->record;
                    }
                                
                    return $positions;
                }
            }
        }
        return array();
        
    }
}

# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
