<?php
/*
 * © Copyright 2007, 2008 IntraHealth International, Inc.
 * 
 * This File is part of iHRIS
 * 
 * iHRIS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/**
 * @package iHRIS
 * @subpackage Manage
 * @author Luke Duncan <lduncan@intrahealth.org>
 * @copyright Copyright &copy; 2007, 2008 IntraHealth International, Inc. 
 * @since v1.0.0
 * @version v2.0.0
 */
/**
 * Object for dealing with people.
 * 
 * @package iHRIS
 * @subpackage Manage
 * @access public
 */
class iHRIS_ManagePerson extends iHRIS_Person {


    
    /**
     * Find and return the most recent position held by this person.
     * 
     * This method only works after the {@link popluateLast} or {@link populateChildren} method has been called with the
     * PersonPosition class as an argument
     * @return I2CE_Form
     */
    public function getLastPosition() {
        $form_name = "person_position";
        $count = count( $this->children[$form_name] );
        if ( $count == 0 ) {
            return null;
        } elseif ( $count == 1 ) {
            return $this->children[$form_name][0];
        } else {
            $last_obj =& $this->children[$form_name][0];
            for( $i = 1; $i < $count; $i++ ) {
                if ( $last_obj->start_date->before( $this->children[$form_name][$i]->start_date ) ) {
                    $last_obj =& $this->children[$form_name][$i];
                }
            }
            return $last_obj;
        }
    }
        
    /**
     * Checks to see if the most recent position for this person is still active and doesn't have an end date
     * for his/her position.
     * @see getLastPosition()
     * @return boolean
     */
    public function isActive() {
        $pers_pos =& $this->getLastPosition();
        if ( $pers_pos == null ) return false;
        if ( isset( $pers_pos->end_date ) && $pers_pos->end_date instanceof I2CE_Date ) {
            if ( $pers_pos->end_date->equals( I2CE_Date::blank() ) ) return true;
            else return false;
        } else {
            return true;
        }
    }
        

    /**
     * Search the database for applicants that have applied to the given position.
     * @param integer $position
     * @return array
     * @see search()
     */
    static public function findApplicants( $position ) {
        $search = array();
        if ( I2CE_ModuleFactory::instance()->isEnabled( "ihris-manage-Application" ) ) {
            $search["application"][] = array( 'field' => 'position', 
                                            'values' => array( array( 'value' => '(^|,)' . $position . '(,|$)', 'method' => 'REGEXP' ) ) );
            return self::search( $search, "AND", "application" );
        } else {
            return self::search( $search );
        }
    }
        

}

# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
