<?php
/*
 * © Copyright 2007, 2008 IntraHealth International, Inc.
 * 
 * This File is part of iHRIS
 * 
 * iHRIS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/**
 * View a person's record.
 * @package iHRIS
 * @subpackage Manage
 * @access public
 * @author Luke Duncan <lduncan@intrahealth.org>
 * @copyright Copyright &copy; 2007, 2008 IntraHealth International, Inc. 
 * @since v2.0.0
 * @version v2.0.0
 */

/**
 * The page class for displaying the a person's record.
 * @package iHRIS
 * @subpackage Manage
 * @access public
 */
class iHRIS_PageViewManage extends iHRIS_PageView {

    /**
     * Perform the main actions of the page.
     */
    protected function action() {
        parent::action();
        $factory = I2CE_FormFactory::instance();
        $child_forms = array(  "benefit", "employment", 
                    "education", "person_language", "person_competency" );
        $global = array( 'person' => true, 'person_position' => true );
        if ( I2CE_ModuleFactory::instance()->isEnabled( "ihris-manage-Application" ) ) {
            $child_forms[] = "application";
            $child_forms[] = "position_decision";
            $child_forms[] = "position_interview";
            $global['application'] = true;
            $global['position_decision'] = true;
        }
        $this->person->populateChildren( $child_forms );
        $this->person->populateLast( array( "person_position" => "start_date" ) ); 
        $pers_pos = $this->person->getLastPosition(); 
        if ( $pers_pos instanceof iHRIS_PersonPosition)  {
            $pers_pos->getField( "position" )->setHref( "view_position?id=" );
            $pers_pos->populateLast(array("salary"=>"start_date"));
            $sg =$factory->createForm("salary_grade", $pers_pos->getSalaryGradeId()); 
            $sg->populate(); 
            $this->template->setForm($sg); 
            $market_rate = $sg->getField('midpoint')->getValue(); 
            $market_rate =$market_rate[1]; 
            $salaryObj  = $pers_pos->children['salary'][0];
            if ($salaryObj instanceof iHRIS_Salary) {
                $this->template->setForm($salaryObj);                   
                $salary = $salaryObj->getField('salary')->getValue();  
                $salary =$salary[1];  
                if ($market_rate != 0) { 
                    $percent = sprintf("%.1f%%",100*(float) $salary/ (float) $market_rate); 
                } else { 
                    $percent = '0%'; 
                } 
                $this->template->setDisplayData("percent_salary",$percent);
            }

        }

        $contact_seen = array();
        foreach( $this->person->children as $form => $list ) {
            foreach( $list as $obj ) {
                if ($obj instanceof I2CE_Form) { 
                    $node = $this->template->appendFileById( "view_" . $form . ".html", "div", $form );
                    $this->template->setForm( $obj,$node);
                    if (isset($global[$form])) {
                        $this->template->setForm( $obj,'siteContent');
                    } 
                    if ( $obj instanceof iHRIS_Contact ) {
                        $contact_seen[ $obj->contact_type ] = true;
                    }
                } else {
                    I2CE::raiseError("Unexpected object type", E_USER_NOTICE);
                }
                if ($form == 'person_position') {
                    $this->template->appendFileById( "view_salary.html", "div", "salary" );
                }
            }
        }
        if ( !array_key_exists( "demographic", $this->person->children ) ) {
            $this->template->addFile( "view_demographic_link.html", "tbody" );
        }


        $contacts = array("TYPE_PERSONAL","TYPE_WORK","TYPE_EMERGENCY","TYPE_OTHER");
        $this->showContacts($contacts,$contact_seen,'hr_staff');

    }
        
}


# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
