<?php
/*
 * © Copyright 2007, 2008 IntraHealth International, Inc.
 * 
 * This File is part of iHRIS
 * 
 * iHRIS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/**
 * View a position's record.
 * @package iHRIS
 * @subpackage Manage
 * @access public
 * @author Luke Duncan <lduncan@intrahealth.org>
 * @copyright Copyright &copy; 2007, 2008 IntraHealth International, Inc. 
 * @since v2.0.0
 * @version v2.0.0
 */

/**
 * The page class for displaying a position's record.
 * @package iHRIS
 * @subpackage Manage
 * @access public
 */
class iHRIS_PageViewPosition extends I2CE_Page {

    /**
     * Perform the main actions of the page.
     */
    protected function action() {
        parent::action();
        $this->template->addHeaderLink("view.js");
        $this->template->appendFileById( "menu_view.html", "li", "navBarUL", true );
        $factory = I2CE_FormFactory::instance();
        $position = $factory->createForm( "position", $this->get('id') );
        $position->getField( "job" )->setHref( "view_job?id=" );
        $position->getField( "supervisor" )->setHref( "view_position?id=" );
        $position->populate();
        $this->template->setForm( $position );
                
        $pers_pos_ids = iHRIS_PersonPosition::getIds( $this->get('id') );
                
        //print_r( $pers_pos_ids );
                
        if ( count($pers_pos_ids) > 0 && $pers_pos_ids['record'] > 0 ) {
            $this->template->appendFileById( "view_position_person.html", "div", "position" );
            $pers_pos = $factory->createForm( "person_position", $pers_pos_ids['record'] );
            $pers_pos->populate();
            $this->template->setForm( $pers_pos );
            $person = $factory->createForm( "person", $pers_pos_ids['parent'] );
            $person->populate();
            $this->template->setForm( $person );
        }
                
        $supervised = $position->getSupervised();
        //print_r( $supervised );
                
        if ( count($supervised) > 0 ) {
            $this->template->appendFileById( "view_position_supervised.html", "div", "position" );
            foreach( $supervised as $record ) {
                $this->template->appendFileById( "view_position_row.html", "tr", "supervised" );
                $this->template->setDisplayData( "position", I2CE_List::lookup( $record, "position" ) );
                $this->template->setDisplayData( "add_pos_id", array("id" => $record ));
            }
            $this->template->setAttribute( "class", "even", "supervised", "tr[position() mod 2 = 0]" );
        }

    }
        
}


# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
