<?php
/*
 * © Copyright 2007, 2008 IntraHealth International, Inc.
 * 
 * This File is part of iHRIS
 * 
 * iHRIS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/**
 * @package iHRIS
 * @subpackage Manage
 * @author Luke Duncan <lduncan@intrahealth.org>
 * @copyright Copyright &copy; 2007, 2008 IntraHealth International, Inc. 
 * @since v1.0.0
 * @version v2.0.0
 */
/**
 * Object for dealing with positions assigned to people.
 * 
 * @package iHRIS
 * @subpackage Manage
 * @access public
 */
class iHRIS_PersonPosition extends I2CE_Form {

    /**
     * Create a new instance of a person position.
     * 
     * @param string $form The name of this form
     * @param integer $id
     */
    public function __construct( $form, $id = 0 ) {
        parent::__construct( $form, $id );
        $this->start_date = I2CE_Date::now();
        $this->end_date = I2CE_Date::blank();
        
    }
    
    /**
     * Return the record id and the parent id for the person position record
     * for the given position.
     * @param integer $position
     * @return array
     */
    static public function getIds( $position ) {
        $pos_det = I2CE_FormField::getFormFieldIdAndType( "person_position", "position" );
        $end_det = I2CE_FormField::getFormFieldIdAndType( "person_position", "end_date" );
        if ( !$pos_det || !$end_det ) return array();
        
        $db = MDB2::singleton();
        if ( !I2CE::pearError( $db, "Error getting database connection: " ) ) {
        
            $row = $db->getRow( "SELECT e1.record FROM last_entry e1 JOIN last_entry e2 ON e1.record = e2.record WHERE e1.form_field = ? AND e2.form_field = ? AND e1." 
                                . $pos_det['type'] . "_value = ? AND e2." . $end_det['type'] . "_value IS NULL", array('integer'),
                                array( $pos_det['id'], $end_det['id'], $position ), array( 'integer', 'integer', 'integer' ) );
                
            if ( !I2CE::pearError( $row, "Errr getting person position ids: " ) ) {
                $record = $row->record;
                
                $form_data = I2CE_Form::getFormData( $record );
        
                return array( 'record' => $record, 'parent' => $form_data['parent'] );
            }
        }
        return array();
        
    }



    public function getSalaryGradeID() {
        $pos_det = I2CE_FormField::getFormFieldIdAndType( "person_position", "position" );
        $job_det = I2CE_FormField::getFormFieldIdAndType( "position", "job" );
        $sg_det = I2CE_FormField::getFormFieldIdAndType( "job", "salary_grade" );
        $qry =
            "SELECT e2.integer_value FROM last_entry e2 " .
            "JOIN last_entry e3 ON e2.record = e3.integer_value " . 
            "JOIN last_entry e4 on e3.record = e4.integer_value " . 
            "WHERE   e2.form_field= ? AND e3.form_field = ? ".
            "  AND e4.form_field = ? AND e4.record = ?";
        $db =& MDB2::singleton(); 
        $row =& $db->getRow($qry, 
                            array('integer'), 
                            array($sg_det['id'],$job_det['id'],$pos_det['id'],$this->getId()),
                            array('integer','integer','integer','integer'));  
            
        return  $row->integer_value;
    }



    /**
     * Constant value for employed
     */
    const STATUS_EMPLOYED =1;
    /**
     * Constant value for not employed
     */
    const STATUS_NOT_EMPLOYED = 2;
    /**
     * @var array Employment Status
     */
    static public $stati = array( self::STATUS_EMPLOYED => 'Employed', self::STATUS_NOT_EMPLOYED => 'Not Employed' );


    /**
     * Lookup the given value from the gender array.
     * @param integer $id
     * @param string $form Not used for this method.
     * @return string
     */
    static public function lookupStatus( $id, $form="" ) {
        return I2CE_Form::lookupArray( $id, self::$stati );
    }
    /**
     * List all the options from the gender array.
     * @param string $form The  form we wish to lookup by
     * @returns array
     */
    static public function listStatusOptions($form ) {
        return  self::$stati ;
    }
        
}

# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
