<?php
/**
 * View a person's record.
 * @package iHRIS
 * @subpackage DemoManagePage
 * @access public
 * @author Carl Leitner <litlfred@ibibilio.org>
 * @copyright Copyright &copy; 2006, 2008 IntraHealth International, Inc. 
 * @since Demo-v2.a
 * @version Demo-v2.a
 */


/**
 * The page class for displaying the a person's salary history
 * @package iHRIS
 * @subpackage DemoManagePage
 * @access public
 */
class iHRIS_SalaryHistoryPage extends I2CE_Page {

    /**
     * Return the title for this page.
     * @return string
     */
    protected function getTitle() { return "Salary History"; }


    /**
     * Load the HTML template files for editing and confirming the index and demographic information.
     */
    protected function loadHTMLTemplates() {
        parent::loadHTMLTemplates();
        $this->template->appendFileById( "menu_view_link.html", "li", "navBarUL", true );
    }
        
    /**
     * Perform the main actions of the page.
     */
    protected function action() {
        parent::action();
        if ($this->get_exists('delete')) {
            $personId = $this->deleteSalary();
            if ($personId > 0) {
                $this->redirect("salary_history?id=$personId");
            } else {
                $this->redirect('');
            }
            return;
        }
        $this->showSalaryHistory();
    }
                

    protected function deleteSalary() {
        if (!$this->get_exists('id')) {
            return false;
        }               
        $id = $this->get('id');
        $factory =& I2CE_FormFactory::instance();
        $salary = $factory->createForm("salary",$id);
        if (!$salary instanceof iHRIS_Salary) {
            return 0;
        }
        $salary->populate();
        $position = $factory->createForm("person_position",$salary->getParent());
        if (!$position instanceof iHRIS_PersonPosition) {
            return 0;
        }
        $position->populate();
        $personID = $position->getParent();
        $salaryIDs = $position->getChildIds('salary','-start_date');
        if (count($salaryIDs) < 2) { //we can only delete if there is at least one salary
            return $personID;
        }
        //we now can delete this history.
        $salary->delete();              
        return $personID;
    }


    protected function showSalaryHistory() {
        $factory =& I2CE_FormFactory::instance();
        $person = $factory->createForm( "person", $this->get('id') );
        $person->populate();
        $this->template->setForm( $person );
        $positionIDs = $person->getChildIds('person_position','-start_date'); //get the positions ordered by descending start date
        $postions = array();
        $this->template->setDisplayData( "history_header",  "Salary History" );
        $firstPosition = true;
        foreach ($positionIDs as $positionId) {
            $position =  $factory->createForm("person_position",$positionId);
            $sg =$factory->createForm("salary_grade", $position->getSalaryGradeId()); 
            if (!$position instanceof iHRIS_PersonPosition) {
                continue;
            }
            $position->populate();
            if ($firstPosition) {
                $firstPosition = false; 
            } else {
                $this->template->appendFileById( "hr.html", "hr", "salary_history" );
            }
            $positionNode = $this->template->appendFileById( "salary_history_position.html", "div", "salary_history" );
            $this->template->setForm($position,$positionNode);
            $salaryListNode = $this->template->getElementById('salary_list');
            if ($salaryListNode instanceof DOMElement) {
                $salaryListNode->setAttribute('id', "salary_list_$positionId");
            }
            $salaryIDs = $position->getChildIds('salary','-start_date');
            foreach ($salaryIDs as $salaryId) {
                $salary = $factory->createForm('salary',$salaryId);
                if (!$salary instanceof iHRIS_Salary) {
                    continue;
                }
                $salary->populate();
                $salaryNode = $this->template->appendFileById( "salary_history_salary.html", "div", "salary_list_$positionId" );
                if (count($salaryIDs) == 1) {
                    $this->template->findAndRemoveNodes(".//*[@id='delete_salary']",$salaryNode);

                }
                $this->template->setForm( $salary,$salaryNode );
            }
            if (count($salaryIDs) == 0) {
                $salaryNode = $this->template->appendFileById( "salary_history_add.html", "div", "salary_list_$positionId" );
                $this->template->appendFileById( "hr.html", "hr", "salary_history" );
            }
            $this->template->setForm( $position, $positionNode );
            if ($sg instanceof iHRIS_SalaryGrade) {
                $sg->populate(); 
                $this->template->setForm( $sg,$positionNode);
            }

        }

    }
        
}



# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
