<?php
/*
 * © Copyright 2007, 2008 IntraHealth International, Inc.
 * 
 * This File is part of iHRIS
 * 
 * iHRIS is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */
/**
 * @package iHRIS
 * @subpackage Manage
 * @author Luke Duncan <lduncan@intrahealth.org>
 * @copyright Copyright &copy; 2007, 2008 IntraHealth International, Inc. 
 * @since v2.0.0
 * @version v2.0.0
 */
/**
 * Object for dealing with selecting search options for the search form..
 * @package iHRIS
 * @subpackage Manage
 * @access public
 */
class iHRIS_Search extends I2CE_Form {

    /**
     * Constant values for limiting search results: include all results.
     */
    const LIMIT_ALL = 1;
    /**
     * Constant values for limiting search results: include applicant results.
     */
    const LIMIT_APPLICANT = 2;
    /**
     * Constant values for limiting search results: include employee results.
     */
    const LIMIT_EMPLOYEE = 3;
    /**
     * Constant values for limiting search results: include old applicant results.
     */
    const LIMIT_OLD_APPLICANT = 4;
    /**
     * Constant values for limiting search results: include old employee results.
     */
    const LIMIT_OLD_EMPLOYEE = 5;

    /**
     * List of choices for limiting search results.
     */
    static public $limit = array( self::LIMIT_ALL  => "All", 
                                  self::LIMIT_EMPLOYEE => "Employee", self::LIMIT_OLD_EMPLOYEE => "Old Employee" );
    /**
     * List of choices for limiting search results with applicant module.
     */
    static public $app_limit = array( self::LIMIT_ALL  => "All", 
                                  self::LIMIT_APPLICANT => "Applicant", self::LIMIT_EMPLOYEE => "Employee", 
                                  self::LIMIT_OLD_APPLICANT => "Old Applicant", self::LIMIT_OLD_EMPLOYEE => "Old Employee" );



    /**
     * Lookup the given value from the limit array.
     * @param integer $id
     * @param string $form Not used for this method.
     * @return string
     */
    static public function lookupLimit( $id, $form="" ) {
        if ( I2CE_ModuleFactory::instance()->isEnabled( "ihris-manage-Application" ) ) {
            return I2CE_Form::lookupArray( $id, self::$app_limit );
        } else {
            return I2CE_Form::lookupArray( $id, self::$limit );
        }
    }
    /**
     * List all the options from the limit array.
     * @param string $form The  form we wish to lookup by
     * @returns array
     */
    static public function listLimitOptions($form ) {
        if ( I2CE_ModuleFactory::instance()->isEnabled( "ihris-manage-Application" ) ) {
            return self::$app_limit;
        } else {
            return self::$limit;
        }
    }
            
}

# Local Variables:
# mode: php
# c-default-style: "bsd"
# indent-tabs-mode: nil
# c-basic-offset: 4
# End:
